Ext.define('CityPlanning.controller.Mapping', {
    extend: 'Ext.app.Controller',
   
    sm: new OpenLayers.Projection("EPSG:3857"), //Spherical Mercator - projection to allow overlays on OSM, Google, Bing, etc.
    wgs: new OpenLayers.Projection("EPSG:4326"),  //WGS84
          
    init: function(){
      mappingController = this;
    },
    
    //-- Creates a layer to hold the markers of a specific incident type
    createMarkerLayer: function(markLabel, markColor){
      if (markColor == null) {
        markColor = 'red';
      }
      var markerLayer = new OpenLayers.Layer.Vector('Marker_'+markLabel,
        { marker: true,
          styleMap: new OpenLayers.StyleMap({
            externalGraphic: 'images/marker-'+markColor+'.png',
            graphicWidth: 21,
            graphicHeight: 25,
            graphicXOffset: -11,
            graphicYOffset: -25
          })
        });
      return markerLayer;
    },
    //-----    
   
    //-- Creates a map with a base layer to be placed in the (mapPanel)
    addMap: function(mapPanel, addBaseLayer, reqProj){
      var bogotaBbox = new OpenLayers.Bounds(-74.2056,4.5851,-73.9731,4.7429) //Extent of the map
      if (reqProj=='sm'){
          bogotaBbox = bogotaBbox.transform(this.wgs, this.sm);
        mapProjection = this.sm
      } else {
        mapProjection = this.wgs
      };
        
      var mapOptions = {
          controls:[],    //Removes all default controls from the map
          projection: mapProjection,  
          units: "m",       //required when using Spherical Mercator
          maxExtent: bogotaBbox  //required when using Spherical Mercator
      };
 
      //Creates a map in the given panel
      var theMap = new OpenLayers.Map(mapPanel.id+'-body', mapOptions); //for Ext 4.2 and up, use '-innerCt' instead of '-body'
      theMap.addControl(new OpenLayers.Control.Navigation());
      theMap.addControl(new OpenLayers.Control.MousePosition());
 
      if (addBaseLayer){  //adds a base layer if requested
          var baseLayer = new OpenLayers.Layer.OSM.TransportMap('Transport Map'); //OpenStreetMap as the base layer of the map
          theMap.addLayer(baseLayer);
      };
 
      return theMap;  //returns the newly created map
    }
    //-----
   
});