Ext.define('CityPlanning.controller.Navigation', {
  extend: 'Ext.app.Controller',
 
  stores: [ 'CitizenReports', 'IncidentTypes' ],
  models: [ 'CitizenReport', 'IncidentType' ],
  views:  [ 'Locations' ],
  
  navMap: null,
 
  init: function() {
    navigationController = this;  //Creates a global variable to access this controller
  },
  
  //-- Creates and displays the navigation map
  displayNavigationMap: function(thePanel){
    if (!this.navMap) {
      this.navMap = mappingController.addMap(thePanel,true,'sm');
      var mapProjection = this.navMap.projection;
      var mapCenter = new OpenLayers.LonLat(-74.0802908,4.64185386).transform(mappingController.wgs, mapProjection);
      this.navMap.setCenter(mapCenter,14);  //Centers the map
      this.navMap.allOverlays = true;
      this.navMap.addControl(new OpenLayers.Control.Attribution());
      this.navMap.addControl(new OpenLayers.Control.ZoomPanel());

      var typesStore = this.getIncidentTypesStore();
      typesStore.each(function(record){
        record.data.layer = mappingController.createMarkerLayer(record.data.abbr, record.data.marker);
        navigationController.navMap.addLayer(record.data.layer);
      });      
      
      selectedFeature = mappingController.createMarkerLayer('HG');
      this.navMap.addLayer(selectedFeature);      
    } else {
      this.navMap.updateSize();  //Refreshes the map on panel resize
    }
  },
  //-----  

  //-- Loads markers on the map, this method is called after the CitizenReports store has been loaded
  loadMarkers: function(){
    var reportsStore = this.getCitizenReportsStore();
    var typesStore = this.getIncidentTypesStore();
    var theLayer, theFeature;
    reportsStore.each(function(record){
      theLayer = typesStore.getById(record.data.reportType).data.layer;
      theFeature = new OpenLayers.Feature.Vector(
        new OpenLayers.Geometry.Point(record.data.lon,record.data.lat).transform(mappingController.wgs,mappingController.sm),
        { 'title' : record.data.title }
      );
      theFeature.fid = record.data.reportId;
      theLayer.addFeatures([theFeature]);
    });

    if ( Ext.getStore('CitizenReports').count()>0 ) {
      this.getController('Reports').focusImage(null,reportsStore.getAt(0));
    }    
  },
  //-----  
 
  //-- Controller's launch function
  onLaunch: function(){
    this.getCitizenReportsStore().load({
      callback: this.loadMarkers,
      scope: this    
    });
  }
  //-----
 
});