Ext.define('CityPlanning.controller.Reports', {
  extend: 'Ext.app.Controller',
 
  stores: [ 'CitizenReports', 'IncidentTypes' ],
  models: [ 'CitizenReport', 'IncidentType' ],
  views:  [ 'ReportsList', 'CloseUp' ],
  
  closeUpMap: null,
  
  init: function() {
    this.control({
      'reportslist': {
        select: this.focusImage,
        itemmouseenter: this.highlightReport,
        itemmouseleave: this.maskReport
      },
      'closeup': {
        afterlayout: this.initCloseUpMap
      }
    });
  },
 
  //-- Initialises the close up map
  initCloseUpMap: function(){
    if (!this.closeUpMap){
      this.closeUpMap = mappingController.addMap(Ext.getCmp('closeUpPanel'),false, 'wgs');
       
      var baseImage = new OpenLayers.Layer.WMS('Aerial Photo',
        'http://imagenes.catastrobogota.gov.co/arcgis/services/Mosaico2009/MapServer/WMSServer?', {
          layers: '1',
          type: "image/png",
        },{ singleTile : true }
      );    
 
      var markerStyle = new OpenLayers.Style({
        pointRadius: 5,
        fillColor:"Aqua",
        fillOpacity:0.4,
        strokeColor:"Aqua",
        strokeOpacity:1,
        strokeWidth:2,
        label: '[${label}]',
        fontColor: "Aqua",
        fontSize: "14px",
        fontFamily: "Courier New, monospace",
        fontWeight: "bold",
        align: "tm",
        labelYOffset: 15
      });
 
      var markLayer = new OpenLayers.Layer.Vector('overlay_marker', {
        styleMap: new OpenLayers.StyleMap({
          'default' : markerStyle
        })
      });
      this.closeUpMap.addLayers([baseImage,markLayer]);
    } else {
      this.closeUpMap.updateSize(); //Refreshes the close up map when required
    }  
  },
  //----- 
 
  //-- Center the closeup view on the selected report
  focusImage: function(grid, record){
    var theLayer = this.closeUpMap.getLayersByName('overlay_marker')[0];
    theLayer.removeAllFeatures();
    theLayer.addFeatures([new OpenLayers.Feature.Vector(
      new OpenLayers.Geometry.Point(record.data.lon,record.data.lat),
      { label : record.data.reportId }
    )]);
    this.closeUpMap.setCenter(new OpenLayers.LonLat(record.data.lon,record.data.lat),8);
  },
  //-----
  
  //-- Highlights/Masks the selected mark on the map
  highlightReport: function(grid, record) {
    var theFeature = new OpenLayers.Feature.Vector(
      new OpenLayers.Geometry.Point(record.get('lon'),record.get('lat')).transform(mappingController.wgs,mappingController.sm)
    );
    selectedFeature.addFeatures([theFeature]);
  },
  //-----
  maskReport: function(grid, record) {
    selectedFeature.removeAllFeatures();
  }
  //-----
  
});